<?php

class Magegiant_Affiliate_Block_Adminhtml_Transaction_Grid extends Mage_Adminhtml_Block_Widget_Grid
{
    public function __construct()
    {
        parent::__construct();
        $this->setId('transactionGrid');
        $this->setDefaultSort('transaction_id');
        $this->setDefaultDir('DESC');
        $this->setUseAjax(true);
        $this->setSaveParametersInSession(true);
    }

    protected function _prepareCollection()
    {
        $collection = Mage::getModel('affiliate/transaction')->getCollection();

        //event to join other table
        Mage::dispatchEvent('affiliate_adminhtml_join_transaction_other_table', array('collection' => $collection));
        $collection->getSelect()
            ->columns(array('customer_email' => 'if (main_table.customer_email="", "N/A", main_table.customer_email)'))
            ->columns(array('order_number' => 'if (main_table.order_number IS NULL OR main_table.order_number="", "N/A", main_table.order_number)'))
            ->columns(array('order_item_names' => 'if (main_table.order_item_names IS NULL, "N/A", main_table.order_item_names)'));
        //Zend_Debug::dump($collection->getSelect()->__toString());
        $this->setCollection($collection);

        return parent::_prepareCollection();
    }

    protected function _prepareColumns()
    {
        $currencyCode = Mage::app()->getStore()->getBaseCurrency()->getCode();

        $this->addColumn('transaction_id', array(
            'header' => Mage::helper('affiliate')->__('ID'),
            'align'  => 'right',
            'width'  => '50px',
            'index'  => 'transaction_id',
        ));


        $this->addColumn('order_item_names', array(
            'header'       => Mage::helper('affiliate')->__('Product Name'),
            'align'        => 'left',
            'index'        => 'order_item_names',
            'filter_index' => 'if (main_table.order_item_names IS NULL, "N/A", main_table.order_item_names)',
            'renderer'     => 'affiliate/adminhtml_transaction_renderer_product',
        ));


        $this->addColumn('account_email', array(
            'header'   => Mage::helper('affiliate')->__('Affiliate Email'),
            'width'    => '150px',
            'index'    => 'account_email',
            'renderer' => 'affiliate/adminhtml_transaction_renderer_account',
        ));

        $this->addColumn('customer_email', array(
            'header'       => Mage::helper('affiliate')->__('Customer Email'),
            'width'        => '150px',
            'align'        => 'left',
            'index'        => 'customer_email',
            'filter_index' => 'if (main_table.customer_email="", "NA", main_table.customer_email)',
            'renderer'     => 'affiliate/adminhtml_transaction_renderer_customer',
        ));

        $this->addColumn('order_number', array(
            'header'       => Mage::helper('affiliate')->__('Order'),
            'width'        => '150px',
            'align'        => 'left',
            'index'        => 'order_number',
            'filter_index' => 'if (main_table.order_number="", "N/A", main_table.order_number)',
            'renderer'     => 'affiliate/adminhtml_transaction_renderer_order',
        ));

        $this->addColumn('total_amount', array(
            'header'        => Mage::helper('affiliate')->__('Total Amount'),
            'width'         => '150px',
            'align'         => 'right',
            'index'         => 'total_amount',
            'type'          => 'price',
            'currency_code' => $currencyCode,
        ));

        $this->addColumn('commission', array(
            'header'        => Mage::helper('affiliate')->__('Commission'),
            'width'         => '150px',
            'align'         => 'right',
            'index'         => 'commission',
            'type'          => 'price',
            'currency_code' => $currencyCode,
        ));

        $this->addColumn('discount', array(
            'header'        => Mage::helper('affiliate')->__('Discount'),
            'width'         => '150px',
            'align'         => 'right',
            'index'         => 'discount',
            'type'          => 'price',
            'currency_code' => $currencyCode,
        ));

        //add event to add more column 
        Mage::dispatchEvent('affiliate_adminhtml_add_column_transaction_grid', array('grid' => $this));

        $this->addColumn('created_time', array(
            'header' => Mage::helper('affiliate')->__('Time'),
            'width'  => '150px',
            'align'  => 'right',
            'index'  => 'created_time',
            'type'   => 'date'
        ));

        $this->addColumn('status', array(
            'header'  => Mage::helper('affiliate')->__('Status'),
            'align'   => 'left',
            'width'   => '80px',
            'index'   => 'status',
            'type'    => 'options',
            'options' => array(
                1 => Mage::helper('affiliate')->__('Completed'),
                2 => Mage::helper('affiliate')->__('Pending'),
                3 => Mage::helper('affiliate')->__('Canceled'),
                4 => Mage::helper('affiliate')->__('On Hold'),
            ),
        ));

        $this->addColumn('store_id', array(
            'header'     => Mage::helper('affiliate')->__('Store view'),
            'align'      => 'left',
            'index'      => 'store_id',
            'type'       => 'store',
            'store_view' => true,
        ));

        $this->addColumn('action',
            array(
                'header'    => Mage::helper('affiliate')->__('Action'),
                'width'     => '100',
                'type'      => 'action',
                'getter'    => 'getId',
                'actions'   => array(
                    array(
                        'caption' => Mage::helper('affiliate')->__('View'),
                        'url'     => array('base' => '*/*/view'),
                        'field'   => 'id'
                    )
                ),
                'filter'    => false,
                'sortable'  => false,
                'index'     => 'stores',
                'is_system' => true,
            ));

        //$this->addExportType('*/*/exportCsv', Mage::helper('affiliate')->__('CSV'));
        //$this->addExportType('*/*/exportXml', Mage::helper('affiliate')->__('XML'));

        return parent::_prepareColumns();
    }

    protected function _prepareMassaction()
    {
        $this->setMassactionIdField('transaction_id');
        $this->getMassactionBlock()->setFormFieldName('transaction');

        $this->getMassactionBlock()->addItem('cancel', array(
            'label'   => Mage::helper('affiliate')->__('Cancel'),
            'url'     => $this->getUrl('*/*/massCancel'),
            'confirm' => Mage::helper('affiliate')->__('This action cannot be restored. Are you sure?'),
        ));

        // add more mass action for transaction grid
        Mage::dispatchEvent('affiliate_adminhtml_add_massaction_transaction_grid', array('grid' => $this));

        return $this;
    }

    public function getRowUrl($row)
    {
        return $this->getUrl('*/*/view', array('id' => $row->getId()));
    }

    public function getGridUrl()
    {
        return $this->getUrl('*/*/grid', array('_current' => true));
    }
}