<?php

require '../vendor/autoload.php';

use \SixBySix\RealtimeDespatch\Api\Credentials;
use SixBySix\RealtimeDespatch\Gateway\Factory\DefaultGatewayFactory;

use \SixBySix\RealtimeDespatch\Entity\Product;
use \SixBySix\RealtimeDespatch\Entity\Order;
use \SixBySix\RealtimeDespatch\Entity\OrderLine;
use \SixBySix\RealtimeDespatch\Entity\Shipment;
use \SixBySix\RealtimeDespatch\Entity\DeliveryAddress;
use \SixBySix\RealtimeDespatch\Entity\InvoiceAddress;
use \SixBySix\RealtimeDespatch\Entity\ShipmentAddress;

$credentials = new Credentials();
$credentials->setEndpoint('https://getsquare.realtimedespatch.co.uk/web/');
$credentials->setChannel('magento');
$credentials->setOrganisation('myco');
$credentials->setUsername('magento');
$credentials->setPassword('getsquare');

$factory = new DefaultGatewayFactory();
$service = new SixBySix\RealtimeDespatch\Service\OrderService($factory->create($credentials));

try
{
    $order = new Order;

    //Params
    $order->setExternalReference('TEST_'.uniqid());
    $order->setState('created');
    $order->setPaymentTransactionInfo(999);
    $order->setCustomerComment('A comment from the customer');
    $order->setTotalPriceNet(10.0);
    $order->setTotalPriceGross(12.0);
    $order->setTotalTax(2.0);
    $order->setTaxCode('T1');
    $order->setShippingPriceNet(2.5);
    $order->setShippingPriceGross(2.0);
    $order->setShippingTax(2.0);
    $order->setShippingTaxCode('T1');
    $order->setCurrency('GBP');
    $order->setCurrencyUnits('pounds');

    // Addresses

    $deliveryAddress = new DeliveryAddress();
    $deliveryAddress->setAddressLine1('Granvilla');
    $deliveryAddress->setAddressLine2('Melton Hill');
    $deliveryAddress->setAddressLine3('Woodbridge');
    $deliveryAddress->setAddressLine4('Suffolk');
    $deliveryAddress->setCountryCode('UK');
    $deliveryAddress->setPostCode('IP12 1AX');
    $deliveryAddress->setContactName('Phil Zoi');
    $deliveryAddress->setEmailAddress('phil@realtimedespatch.co.uk');
    $deliveryAddress->setDayPhoneNumber('01394 384181');
    $deliveryAddress->setEveningPhoneNumber('01394 385000');
    $deliveryAddress->setMobilePhoneNumber('07595 524200');
    $deliveryAddress->setFaxNumber('01394 384181');
    $deliveryAddress->setCompanyName('Realtime Despatch');
    $order->setDeliveryAddress($deliveryAddress);

    $invoiceAddress = new InvoiceAddress();
    $invoiceAddress->setAddressLine1('Realtime Despatch');
    $invoiceAddress->setAddressLine2('2 Manor Cottages');
    $invoiceAddress->setAddressLine3('Swindon Road');
    $invoiceAddress->setAddressLine4('Kington Langley');
    $invoiceAddress->setAddressLine5('Chippenham');
    $invoiceAddress->setAddressLine6('Wiltshire');
    $invoiceAddress->setCountryCode('UK');
    $invoiceAddress->setPostCode('SN15 5ND');
    $invoiceAddress->setContactName('Charlie Armor');
    $invoiceAddress->setEmailAddress('charlie@realtimedespatch.co.uk');
    $invoiceAddress->setDayPhoneNumber('01249 750564');
    $invoiceAddress->setEveningPhoneNumber('01249 750564');
    $invoiceAddress->setFaxNumber('01249 750564');
    $invoiceAddress->setCompanyName('Realtime Despatch');
    $order->setInvoiceAddress($invoiceAddress);

    // Order Lines

    $orderLine1 = new OrderLine();
    $orderLine1->setProduct(new Product('UniCharge35'));
    $orderLine1->setQuantity(2);
    $orderLine1->setTotalPriceNet(4.0);
    $orderLine1->setTotalPriceGross(5.0);
    $orderLine1->setTotalTax(1.0);
    $orderLine1->setTotalTaxCode('T1');
    $order->addLine($orderLine1);

    $orderLine2 = new OrderLine();
    $orderLine2->setProduct(new Product('HTC03456'));
    $orderLine2->setQuantity(4);
    $orderLine2->setTotalPriceNet(6.0);
    $orderLine2->setTotalPriceGross(7.0);
    $orderLine2->setTotalTax(1.0);
    $orderLine2->setTotalTaxCode('T2');
    $order->addLine($orderLine2);

    // Shipment

    $shipment = new Shipment;
    $shipment->setEarliestShipDate('2014-06-20');
    $shipment->setDeliveryInstruction('Please leave with neighbour if nobody at home');
    $shipment->setWeight(120);
    $shipment->setDeliverySuggestionCode('express');
    $shipment->setDeliverySuggestionName('Express');
    $order->setShipment($shipment);

    $importReport = $service->importOrder($order);

    foreach ($importReport->getLines() as $line) {
        echo $line->getMessage()."\n";
    }

    // Retrieve Order Details

    $service->retrieveOrderDetails($order);

    // Cancel Order

    $service->cancelOrder($order);
}
catch (Exception $ex)
{
    var_dump($ex->getMessage());
}